@@ -109,7 +109,17 @@ class TestCreateSubnetPool(TestSubnetPool):
         arglist = []
         verifylist = []
 
-        # Missing required args should bail here
+        self.assertRaises(tests_utils.ParserException, self.check_parser,
+                          self.cmd, arglist, verifylist)
+
+    def test_create_no_pool_prefix(self):
+        """Make sure --pool-prefix is a required argument"""
+        arglist = [
+            self._subnet_pool.name,
+        ]
+        verifylist = [
+            ('name', self._subnet_pool.name),
+        ]
         self.assertRaises(tests_utils.ParserException, self.check_parser,
                           self.cmd, arglist, verifylist)
 
@@ -138,23 +148,26 @@ class TestCreateSubnetPool(TestSubnetPool):
             '--default-prefix-length', self._subnet_pool.default_prefixlen,
             '--max-prefix-length', self._subnet_pool.max_prefixlen,
             '--min-prefix-length', self._subnet_pool.min_prefixlen,
+            '--pool-prefix', '10.0.10.0/24',
             self._subnet_pool.name,
         ]
         verifylist = [
-            ('default_prefix_length', self._subnet_pool.default_prefixlen),
-            ('max_prefix_length', self._subnet_pool.max_prefixlen),
-            ('min_prefix_length', self._subnet_pool.min_prefixlen),
+            ('default_prefix_length',
+                int(self._subnet_pool.default_prefixlen)),
+            ('max_prefix_length', int(self._subnet_pool.max_prefixlen)),
+            ('min_prefix_length', int(self._subnet_pool.min_prefixlen)),
             ('name', self._subnet_pool.name),
+            ('prefixes', ['10.0.10.0/24']),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
         columns, data = (self.cmd.take_action(parsed_args))
 
         self.network.create_subnet_pool.assert_called_once_with(**{
-            'default_prefixlen': self._subnet_pool.default_prefixlen,
-            'max_prefixlen': self._subnet_pool.max_prefixlen,
-            'min_prefixlen': self._subnet_pool.min_prefixlen,
-            'prefixes': [],
+            'default_prefixlen': int(self._subnet_pool.default_prefixlen),
+            'max_prefixlen': int(self._subnet_pool.max_prefixlen),
+            'min_prefixlen': int(self._subnet_pool.min_prefixlen),
+            'prefixes': ['10.0.10.0/24'],
             'name': self._subnet_pool.name,
         })
         self.assertEqual(self.columns, columns)
@@ -221,6 +234,32 @@ class TestCreateSubnetPool(TestSubnetPool):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.data, data)
 
+    def test_create_default_and_shared_options(self):
+        arglist = [
+            '--pool-prefix', '10.0.10.0/24',
+            '--default',
+            '--share',
+            self._subnet_pool.name,
+        ]
+        verifylist = [
+            ('prefixes', ['10.0.10.0/24']),
+            ('default', True),
+            ('share', True),
+            ('name', self._subnet_pool.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        columns, data = (self.cmd.take_action(parsed_args))
+
+        self.network.create_subnet_pool.assert_called_once_with(**{
+            'is_default': True,
+            'name': self._subnet_pool.name,
+            'prefixes': ['10.0.10.0/24'],
+            'shared': True,
+        })
+        self.assertEqual(self.columns, columns)
+        self.assertEqual(self.data, data)
+
 
 class TestDeleteSubnetPool(TestSubnetPool):
 
@@ -267,6 +306,8 @@ class TestListSubnetPool(TestSubnetPool):
     columns_long = columns + (
         'Default Prefix Length',
         'Address Scope',
+        'Default Subnet Pool',
+        'Shared',
     )
 
     data = []
@@ -285,6 +326,8 @@ class TestListSubnetPool(TestSubnetPool):
             utils.format_list(pool.prefixes),
             pool.default_prefixlen,
             pool.address_scope_id,
+            pool.is_default,
+            pool.shared,
         ))
 
     def setUp(self):
@@ -354,8 +397,8 @@ class TestSetSubnetPool(TestSubnetPool):
         ]
         verifylist = [
             ('name', 'noob'),
-            ('default_prefix_length', '8'),
-            ('min_prefix_length', '8'),
+            ('default_prefix_length', 8),
+            ('min_prefix_length', 8),
             ('subnet_pool', self._subnet_pool.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -364,8 +407,8 @@ class TestSetSubnetPool(TestSubnetPool):
 
         attrs = {
             'name': 'noob',
-            'default_prefixlen': '8',
-            'min_prefixlen': '8',
+            'default_prefixlen': 8,
+            'min_prefixlen': 8,
         }
         self.network.update_subnet_pool.assert_called_once_with(
             self._subnet_pool, **attrs)
@@ -380,7 +423,7 @@ class TestSetSubnetPool(TestSubnetPool):
         ]
         verifylist = [
             ('prefixes', ['10.0.1.0/24', '10.0.2.0/24']),
-            ('max_prefix_length', '16'),
+            ('max_prefix_length', 16),
             ('subnet_pool', self._subnet_pool.name),
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
@@ -391,7 +434,7 @@ class TestSetSubnetPool(TestSubnetPool):
         prefixes.extend(self._subnet_pool.prefixes)
         attrs = {
             'prefixes': prefixes,
-            'max_prefixlen': '16',
+            'max_prefixlen': 16,
         }
         self.network.update_subnet_pool.assert_called_once_with(
             self._subnet_pool, **attrs)
@@ -474,6 +517,62 @@ class TestSetSubnetPool(TestSubnetPool):
         self.assertRaises(tests_utils.ParserException, self.check_parser,
                           self.cmd, arglist, verifylist)
 
+    def test_set_default(self):
+        arglist = [
+            '--default',
+            self._subnet_pool.name,
+        ]
+        verifylist = [
+            ('default', True),
+            ('subnet_pool', self._subnet_pool.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        attrs = {
+            'is_default': True
+        }
+        self.network.update_subnet_pool.assert_called_once_with(
+            self._subnet_pool, **attrs)
+        self.assertIsNone(result)
+
+    def test_set_no_default(self):
+        arglist = [
+            '--no-default',
+            self._subnet_pool.name,
+        ]
+        verifylist = [
+            ('no_default', True),
+            ('subnet_pool', self._subnet_pool.name),
+        ]
+        parsed_args = self.check_parser(self.cmd, arglist, verifylist)
+
+        result = self.cmd.take_action(parsed_args)
+
+        attrs = {
+            'is_default': False,
+        }
+        self.network.update_subnet_pool.assert_called_once_with(
+            self._subnet_pool, **attrs)
+        self.assertIsNone(result)
+
+    def test_set_no_default_conflict(self):
+        arglist = [
+            '--default',
+            '--no-default',
+            self._subnet_pool.name,
+        ]
+        verifylist = [
+            ('default', True),
+            ('no_default', True),
+            ('subnet_pool', self._subnet_pool.name),
+        ]
+
+        # Exclusive arguments will conflict here.
+        self.assertRaises(tests_utils.ParserException, self.check_parser,
+                          self.cmd, arglist, verifylist)
+
 
 class TestShowSubnetPool(TestSubnetPool):
 
@@ -524,7 +623,6 @@ class TestShowSubnetPool(TestSubnetPool):
         arglist = []
         verifylist = []
 
-        # Missing required args should bail here
         self.assertRaises(tests_utils.ParserException, self.check_parser,
                           self.cmd, arglist, verifylist)
 
